@@ -43,14 +43,14 @@ class AiGabor : public Ai, public AiTimeOver {
 public:
     explicit AiGabor(const Dimension& dimension, KgDifficultyLevel::StandardLevel skill, Player player);
     virtual ~AiGabor();
-    virtual void cancelAndWait();
-    virtual bool isTimeOver();
+    void cancelAndWait() Q_DECL_OVERRIDE;
+    bool isTimeOver() Q_DECL_OVERRIDE;
 
 public slots:
-    virtual void changeBoard(const Move& move);
-    virtual void gameOver();
-    virtual void setSkill(KgDifficultyLevel::StandardLevel skill);
-    virtual void slotMove();
+    void changeBoard(const Move& move) Q_DECL_OVERRIDE;
+    void gameOver() Q_DECL_OVERRIDE;
+    void setSkill(KgDifficultyLevel::StandardLevel skill) Q_DECL_OVERRIDE;
+    void slotMove() Q_DECL_OVERRIDE;
 
 signals:
     void move(const Move& move);
